==> haskell-digest-0.0.1.2-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-digest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 digest
version:              0.0.1.2
visibility:           public
id:                   digest-0.0.1.2-Iu52ykWfDJYHHg7nkuSlr9
key:                  digest-0.0.1.2-Iu52ykWfDJYHHg7nkuSlr9
license:              BSD-3-Clause
copyright:            (c) 2009 Eugene Kirpichov
maintainer:           Eugene Kirpichov <ekirpichov@gmail.com>
author:               Eugene Kirpichov <ekirpichov@gmail.com>
stability:            provisional
synopsis:
    Various cryptographic hashes for bytestrings; CRC32 and Adler32 for now.

description:
    This package provides efficient cryptographic hash implementations for
    strict and lazy bytestrings. For now, CRC32 and Adler32 are supported;
    they are implemented as FFI bindings to efficient code from zlib.

category:             Cryptography
abi:                  7a78ca573a4651a94a9851482727b7bf
exposed:              True
exposed-modules:      Data.Digest.Adler32 Data.Digest.CRC32
import-dirs:          /usr/lib/ghc-8.10.2/site-local/digest-0.0.1.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/digest-0.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/digest-0.0.1.2
hs-libraries:         HSdigest-0.0.1.2-Iu52ykWfDJYHHg7nkuSlr9
extra-libraries:      z
includes:             zlib.h
depends:              base-4.14.1.0 bytestring-0.10.10.0
haddock-interfaces:   /usr/share/doc/haskell-digest/html/digest.haddock
haddock-html:         /usr/share/doc/haskell-digest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-digest-0.0.1.2-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-digest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 digest
version:              0.0.1.2
visibility:           public
id:                   digest-0.0.1.2-Bwle4kRYTmNK4uaWg48glg
key:                  digest-0.0.1.2-Bwle4kRYTmNK4uaWg48glg
license:              BSD-3-Clause
copyright:            (c) 2009 Eugene Kirpichov
maintainer:           Eugene Kirpichov <ekirpichov@gmail.com>
author:               Eugene Kirpichov <ekirpichov@gmail.com>
stability:            provisional
synopsis:
    Various cryptographic hashes for bytestrings; CRC32 and Adler32 for now.

description:
    This package provides efficient cryptographic hash implementations for
    strict and lazy bytestrings. For now, CRC32 and Adler32 are supported;
    they are implemented as FFI bindings to efficient code from zlib.

category:             Cryptography
abi:                  2f0875b2951e6c9bbaec81fdc4f302aa
exposed:              True
exposed-modules:      Data.Digest.Adler32 Data.Digest.CRC32
import-dirs:          /usr/lib/ghc-8.10.3/site-local/digest-0.0.1.2
library-dirs:         /usr/lib/ghc-8.10.3/site-local/digest-0.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/digest-0.0.1.2
hs-libraries:         HSdigest-0.0.1.2-Bwle4kRYTmNK4uaWg48glg
extra-libraries:      z
includes:             zlib.h
depends:              base-4.14.1.0 bytestring-0.10.12.0
haddock-interfaces:   /usr/share/doc/haskell-digest/html/digest.haddock
haddock-html:         /usr/share/doc/haskell-digest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
